function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var fetch = _interopDefault(require('node-fetch'));

function makeUrl(chunks, interpolations, pastLast) {
  if ( pastLast === void 0 ) pastLast = false;

  var str = "";
  var lastIndex = 0;

  if (pastLast) {
    lastIndex = interpolations.length - 1;
  }

  var length = chunks.length;

  for (var i = 0; i < length; i++) {
    var key = chunks[i];
    var keyLength = key.length;
    var value = interpolations[i];

    if (pastLast && i === lastIndex) {
      str += key;
      continue;
    }

    if (value !== undefined) {
      if (typeof value === "object") {
        if (key[keyLength - 1] === "?") {
          var generate = generateFromObject(value, "=", "&");
          str += "" + key + generate;
        } else {
          if (key[keyLength - 1] !== "\n") {
            var generateParams = generateFromObject(value, "/", "/");
            str += "" + key + generateParams;
          }
        }

        continue;
      }

      value += "";
    } else {
      str += key;
      continue;
    }

    value += "";
    str += "" + key + value;
  }

  return str;
}

function generateFromObject(obj, join1, join2) {
  return Object.keys(obj).map(function (prop) {
    return [prop, obj[prop]].map(encodeURIComponent).join(join1);
  }).join(join2);
}

function parseHeaders(url) {
  var getIndex = url.indexOf("\n");
  var headers = {};
  var pureUrl = url;

  if (getIndex !== -1) {
    pureUrl = url.slice(0, getIndex);
    url.slice(getIndex).trim().split("\n").forEach(function (value) {
      var getSymbol = value.indexOf(":");
      var key = value.slice(0, getSymbol).trim();
      var val = value.slice(getSymbol + 1, value.length).trim();
      headers[key] = val;
    });
  }

  return {
    headers: headers,
    pureUrl: pureUrl
  };
}

var handleResponse = function (response) {
  try {
    var _exit = false;

    var _temp = function () {
      if (/^application\/json/.test(response.headers.get("content-type"))) {
        return Promise.resolve(response.json()).then(function (data) {
          _exit = true;
          return {
            response: response,
            data: data
          };
        });
      }
    }();

    return Promise.resolve(_temp && _temp.then ? _temp.then(function (_result) {
      return _exit ? _result : response;
    }) : _exit ? _temp : response);
  } catch (e) {
    return Promise.reject(e);
  }
};

var post = function (chunks) {
  var interpolations = [], len = arguments.length - 1;
  while ( len-- > 0 ) interpolations[ len ] = arguments[ len + 1 ];

  try {
    var url = makeUrl(chunks, interpolations, true);
    var ref = parseHeaders(url);
    var headers = ref.headers;
    var pureUrl = ref.pureUrl;
    var postData = interpolations[interpolations.length - 1];

    if (typeof postData === "object") {
      if (!headers["Content-Type"]) {
        postData = JSON.stringify(postData);
        headers["Content-Type"] = "application/json";
      }
    }

    return Promise.resolve(fetch(pureUrl, {
      method: "POST",
      body: postData,
      headers: headers
    })).then(function (response) {
      return Promise.resolve(handleResponse(response));
    });
  } catch (e) {
    return Promise.reject(e);
  }
};

var get = function (chunks) {
  var interpolations = [], len = arguments.length - 1;
  while ( len-- > 0 ) interpolations[ len ] = arguments[ len + 1 ];

  try {
    var url = makeUrl(chunks, interpolations);
    var ref = parseHeaders(url);
    var headers = ref.headers;
    var pureUrl = ref.pureUrl;
    return Promise.resolve(fetch(pureUrl, {
      method: "GET",
      headers: headers
    })).then(function (response) {
      return Promise.resolve(handleResponse(response));
    });
  } catch (e) {
    return Promise.reject(e);
  }
};

exports.get = get;
exports.post = post;
